﻿using System.ComponentModel;
using System.Diagnostics.Eventing.Reader;
using System.Runtime.CompilerServices;
using Wisej.Web;

namespace Wisej.CommandBindingSample
{
    public class DataRecord : INotifyPropertyChanged
    {
        private string _name = string.Empty;
        private string _description = string.Empty;

        public DataRecord()
        {
            this.ChangeName = new Command<DataRecord>(
                this.DoChangeName,
                this.CanChangeName
            );
        }

        public void ChangeValue<T>(ref T field, T value, [CallerMemberName] string name = null)
        {
            if (!field.Equals(value))
            {
                field = value;
                this.PropertyChanged?.Invoke(this, new PropertyChangedEventArgs(name));
            }
        }

        public string Name
        {
            get => _name;

            set => ChangeValue(ref _name, value);
        }

        public string Description
        {
            get => _description;

            set => ChangeValue(ref _description, value);
        }

        public event PropertyChangedEventHandler PropertyChanged;

        public ICommand ChangeName { get; set; }


        public bool CanChangeName(CommandArgs<DataRecord> args)
        {
            if (args.DataItem.Name == "Name 0")
                return false;

            return true;
        }

        public void DoChangeName(CommandArgs<DataRecord> args)
        {
            args.DataItem.Name = $"New {Name}";
        }
    }
}
